# TVN
Tiny Video Networks

![TVN architecture](https://github.com/DELTA37/TVN/blob/main/static/tvn.png)

You can install tvn package via pip soon...  
pip install torch-tvn  


After installing or cloning  
>> import tvn  
>> from tvn.data import SomethingSomethingV2  
>> from tvn.config import CFG1  
>> from tvn.model import TVN  
>> from tvn.solver import Solver  


You should download data from [SomethingSomethingV2 dataset](https://20bn.com/datasets/something-something)  
And place it in ./data folder  
After that you can start training via script train.py  
>> python train.py  

Pretrained models will be as soon as issue with this question appears :)  

You can specify your own config in the way as in tvn.config  

If you find any bugs please contact me..  
